@@ -23,11 +23,10 @@ import jsii
 import jsii.compat
 import publication
 
-import aws_cdk.core
-import constructs
-
 from ._jsii import *
 
+import aws_cdk.core
+
 
 @jsii.implements(aws_cdk.core.IInspectable)
 class CfnAssessmentTarget(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-inspector.CfnAssessmentTarget"):
@@ -118,7 +117,7 @@ class CfnAssessmentTarget(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsi
         return jsii.get(self, "assessmentTargetName")
 
     @assessment_target_name.setter
-    def assessment_target_name(self, value: typing.Optional[str]):
+    def assessment_target_name(self, value: typing.Optional[str]) -> None:
         jsii.set(self, "assessmentTargetName", value)
 
     @builtins.property
@@ -132,7 +131,7 @@ class CfnAssessmentTarget(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsi
         return jsii.get(self, "resourceGroupArn")
 
     @resource_group_arn.setter
-    def resource_group_arn(self, value: typing.Optional[str]):
+    def resource_group_arn(self, value: typing.Optional[str]) -> None:
         jsii.set(self, "resourceGroupArn", value)
 
 
@@ -189,7 +188,7 @@ class CfnAssessmentTemplate(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, j
     cloudformationResource:
     :cloudformationResource:: AWS::Inspector::AssessmentTemplate
     """
-    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, assessment_target_arn: str, duration_in_seconds: jsii.Number, rules_package_arns: typing.List[str], assessment_template_name: typing.Optional[str]=None, user_attributes_for_findings: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]]]]=None) -> None:
+    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, assessment_target_arn: str, duration_in_seconds: jsii.Number, rules_package_arns: typing.List[str], assessment_template_name: typing.Optional[str]=None, user_attributes_for_findings: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]]]=None) -> None:
         """Create a new ``AWS::Inspector::AssessmentTemplate``.
 
         :param scope: - scope in which this resource is defined.
@@ -272,7 +271,7 @@ class CfnAssessmentTemplate(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, j
         return jsii.get(self, "assessmentTargetArn")
 
     @assessment_target_arn.setter
-    def assessment_target_arn(self, value: str):
+    def assessment_target_arn(self, value: str) -> None:
         jsii.set(self, "assessmentTargetArn", value)
 
     @builtins.property
@@ -286,7 +285,7 @@ class CfnAssessmentTemplate(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, j
         return jsii.get(self, "durationInSeconds")
 
     @duration_in_seconds.setter
-    def duration_in_seconds(self, value: jsii.Number):
+    def duration_in_seconds(self, value: jsii.Number) -> None:
         jsii.set(self, "durationInSeconds", value)
 
     @builtins.property
@@ -300,7 +299,7 @@ class CfnAssessmentTemplate(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, j
         return jsii.get(self, "rulesPackageArns")
 
     @rules_package_arns.setter
-    def rules_package_arns(self, value: typing.List[str]):
+    def rules_package_arns(self, value: typing.List[str]) -> None:
         jsii.set(self, "rulesPackageArns", value)
 
     @builtins.property
@@ -314,12 +313,12 @@ class CfnAssessmentTemplate(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, j
         return jsii.get(self, "assessmentTemplateName")
 
     @assessment_template_name.setter
-    def assessment_template_name(self, value: typing.Optional[str]):
+    def assessment_template_name(self, value: typing.Optional[str]) -> None:
         jsii.set(self, "assessmentTemplateName", value)
 
     @builtins.property
     @jsii.member(jsii_name="userAttributesForFindings")
-    def user_attributes_for_findings(self) -> typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]]]]:
+    def user_attributes_for_findings(self) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]]]:
         """``AWS::Inspector::AssessmentTemplate.UserAttributesForFindings``.
 
         see
@@ -328,13 +327,13 @@ class CfnAssessmentTemplate(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, j
         return jsii.get(self, "userAttributesForFindings")
 
     @user_attributes_for_findings.setter
-    def user_attributes_for_findings(self, value: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]]]]):
+    def user_attributes_for_findings(self, value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]]]) -> None:
         jsii.set(self, "userAttributesForFindings", value)
 
 
 @jsii.data_type(jsii_type="@aws-cdk/aws-inspector.CfnAssessmentTemplateProps", jsii_struct_bases=[], name_mapping={'assessment_target_arn': 'assessmentTargetArn', 'duration_in_seconds': 'durationInSeconds', 'rules_package_arns': 'rulesPackageArns', 'assessment_template_name': 'assessmentTemplateName', 'user_attributes_for_findings': 'userAttributesForFindings'})
 class CfnAssessmentTemplateProps():
-    def __init__(self, *, assessment_target_arn: str, duration_in_seconds: jsii.Number, rules_package_arns: typing.List[str], assessment_template_name: typing.Optional[str]=None, user_attributes_for_findings: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]]]]=None) -> None:
+    def __init__(self, *, assessment_target_arn: str, duration_in_seconds: jsii.Number, rules_package_arns: typing.List[str], assessment_template_name: typing.Optional[str]=None, user_attributes_for_findings: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]]]=None) -> None:
         """Properties for defining a ``AWS::Inspector::AssessmentTemplate``.
 
         :param assessment_target_arn: ``AWS::Inspector::AssessmentTemplate.AssessmentTargetArn``.
@@ -391,7 +390,7 @@ class CfnAssessmentTemplateProps():
         return self._values.get('assessment_template_name')
 
     @builtins.property
-    def user_attributes_for_findings(self) -> typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]]]]:
+    def user_attributes_for_findings(self) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]]]:
         """``AWS::Inspector::AssessmentTemplate.UserAttributesForFindings``.
 
         see
@@ -497,7 +496,7 @@ class CfnResourceGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_t
         return jsii.get(self, "resourceGroupTags")
 
     @resource_group_tags.setter
-    def resource_group_tags(self, value: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]]):
+    def resource_group_tags(self, value: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]]) -> None:
         jsii.set(self, "resourceGroupTags", value)
 
 
